@@ -1,11 +1,10 @@
 #!/bin/bash
 # Copyright (c) 2020 Red Hat, Inc.
 
-git config --global url."https://$GITHUB_TOKEN@github.com/open-cluster-management".insteadOf "https://github.com/open-cluster-management"
-
 WORKDIR=`pwd`
 cd ${WORKDIR}/..
-git clone --depth 1 -b release-2.2 https://github.com/open-cluster-management/observability-kind-cluster.git
+git config --global url."https://$GITHUB_TOKEN@github.com/stolostron".insteadOf  "https://github.com/stolostron"
+git clone --depth 1 -b release-2.2 https://github.com/stolostron/observability-kind-cluster.git
 cd observability-kind-cluster
 ./setup.sh $1
 if [ $? -ne 0 ]; then
@@ -14,7 +13,7 @@ if [ $? -ne 0 ]; then
 fi
 
 cd ${WORKDIR}/..
-git clone --depth 1 -b release-2.2 https://github.com/open-cluster-management/observability-e2e-test.git
+git clone --depth 1 -b release-2.2 https://github.com/stolostron/observability-e2e-test.git
 cd observability-e2e-test
 
 # run test cases
