@@ -5,7 +5,7 @@ import (
 	"testing"
 
 	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
-	"github.com/open-cluster-management/multicluster-monitoring-operator/pkg/apis"
+	"github.com/stolostron/multicluster-monitoring-operator/pkg/apis"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/kubectl/pkg/scheme"
